==> syd-3.26.0.tar.gz: syd-v3.26.0/dev/ink-perf.sh <==
#!/bin/bash
#
# Compile InkScape under Syd under Perf.
#
# Copyright 2024 Ali Polatel <alip@chesswob.org>
#
# SPDX-License-Identifier: GPL-3.0-or-later

if [[ ${#} -lt 1 ]]; then
    echo >&2 "Usage: ${0##*/} <perf-arguments>..."
    exit 1
fi

# Make sure we don't trigger TPE.
umask 077

# Disable coredumps.
ulimit -c 0

set -ex
if [[ ! -d "${HOME}"/src/inkscape ]]; then
    pushd "${HOME}"/src
    git clone --depth 1 --recursive https://gitlab.com/inkscape/inkscape.git
    popd
fi

PERF="${PERF:-perf}"
SYD="${CARGO_BIN_EXE_syd:-syd}"
exec "${PERF}" "${@}" -- \
    "${SYD}" -q -ppaludis -pli \
        -m "allow/read,stat+/include/***" \
        -m "allow/read,stat,write,exec,ioctl+${DIR}/***" \
        -m "allow/lock/read+/home" \
        -m "allow/read,stat+/home/***" \
        -- bash -ex <<'EOF'
export CFLAGS="-O2 -march=native -mtune=native -flto"
export CXXFLAGS="-O2 -march=native -mtune=native -flto"
DIR="$(mktemp -d --tmpdir=/tmp syd-ink.XXXXX)"
pushd "${DIR}"
cp -ax ~/src/inkscape .
pushd inkscape
CMAKE=(
-DBUILD_SHARED_LIBS:BOOL=TRUE
-DPACKAGE_LOCALE_DIR:PATH=/usr/share/locale
-DENABLE_BINRELOC:BOOL=FALSE
-DINKSCAPE_DATADIR:PATH=/usr/share
-DINKSCAPE_SHARE_INSTALL:PATH=/usr/share
-DLPE_ENABLE_TEST_EFFECTS:BOOL=FALSE
-DSHARE_INSTALL:PATH=/usr/share
-DWITH_ASAN:BOOL=FALSE
-DWITH_GNU_READLINE:BOOL=TRUE
-DWITH_GSOURCEVIEW:BOOL=FALSE
-DWITH_GSPELL:BOOL=TRUE
-DWITH_INTERNAL_2GEOM:BOOL=FALSE
-DWITH_INTERNAL_CAIRO:BOOL=FALSE
-DWITH_JEMALLOC:BOOL=FALSE
-DWITH_LPETOOL:BOOL=FALSE
-DWITH_MANPAGE_COMPRESSION:BOOL=TRUE
-DWITH_NLS:BOOL=TRUE
-DWITH_PROFILING:BOOL=FALSE
-DWITH_SVG2:BOOL=TRUE
-DWITH_X11:BOOL=TRUE
-DENABLE_POPPLER:BOOL=TRUE
-DENABLE_POPPLER_CAIRO:BOOL=TRUE
-DWITH_OPENMP:BOOL=TRUE
-DWITH_IMAGE_MAGICK:BOOL=FALSE
-DWITH_GRAPHICS_MAGICK:BOOL=TRUE
)
cmake ${CMAKE[@]} .
make -j$(nproc) VERBOSE=1
EOF

==> syd-3.29.2.tar.gz: syd-v3.29.2/dev/ink-perf.sh <==
#!/bin/bash
#
# Compile InkScape under Syd under Perf.
#
# Copyright 2024 Ali Polatel <alip@chesswob.org>
#
# SPDX-License-Identifier: GPL-3.0

if [[ ${#} -lt 1 ]]; then
    echo >&2 "Usage: ${0##*/} <perf-arguments>..."
    exit 1
fi

# Make sure we don't trigger TPE.
umask 077

# Disable coredumps.
ulimit -c 0

set -ex
if [[ ! -d "${HOME}"/src/inkscape ]]; then
    pushd "${HOME}"/src
    git clone --depth 1 --recursive https://gitlab.com/inkscape/inkscape.git
    popd
fi

PERF="${PERF:-perf}"
SYD="${CARGO_BIN_EXE_syd:-syd}"
exec "${PERF}" "${@}" -- \
    "${SYD}" -q -ppaludis -pli \
        -m "allow/read,stat+/include/***" \
        -m "allow/read,stat,write,exec,create,node,ioctl+${DIR}/***" \
        -m "allow/lock/read+/home" \
        -m "allow/read,stat+/home/***" \
        -- bash -ex <<'EOF'
export CFLAGS="-O2 -march=native -mtune=native -flto"
export CXXFLAGS="-O2 -march=native -mtune=native -flto"
DIR="$(mktemp -d --tmpdir=/tmp syd-ink.XXXXX)"
pushd "${DIR}"
cp -ax ~/src/inkscape .
pushd inkscape
CMAKE=(
-DBUILD_SHARED_LIBS:BOOL=TRUE
-DPACKAGE_LOCALE_DIR:PATH=/usr/share/locale
-DENABLE_BINRELOC:BOOL=FALSE
-DINKSCAPE_DATADIR:PATH=/usr/share
-DINKSCAPE_SHARE_INSTALL:PATH=/usr/share
-DLPE_ENABLE_TEST_EFFECTS:BOOL=FALSE
-DSHARE_INSTALL:PATH=/usr/share
-DWITH_ASAN:BOOL=FALSE
-DWITH_GNU_READLINE:BOOL=TRUE
-DWITH_GSOURCEVIEW:BOOL=FALSE
-DWITH_GSPELL:BOOL=TRUE
-DWITH_INTERNAL_2GEOM:BOOL=FALSE
-DWITH_INTERNAL_CAIRO:BOOL=FALSE
-DWITH_JEMALLOC:BOOL=FALSE
-DWITH_LPETOOL:BOOL=FALSE
-DWITH_MANPAGE_COMPRESSION:BOOL=TRUE
-DWITH_NLS:BOOL=TRUE
-DWITH_PROFILING:BOOL=FALSE
-DWITH_SVG2:BOOL=TRUE
-DWITH_X11:BOOL=TRUE
-DENABLE_POPPLER:BOOL=TRUE
-DENABLE_POPPLER_CAIRO:BOOL=TRUE
-DWITH_OPENMP:BOOL=TRUE
-DWITH_IMAGE_MAGICK:BOOL=FALSE
-DWITH_GRAPHICS_MAGICK:BOOL=TRUE
)
cmake ${CMAKE[@]} .
make -j$(nproc) VERBOSE=1
EOF
